@@ -5,6 +5,6 @@ from typing import List
 from fast_mda_traceroute.typing import IPAddress
 
 
-def resolve(host) -> List[IPAddress]:
+def resolve(host: str) -> List[IPAddress]:
     info = getaddrinfo(host, None)
     return list(set(ip_address(addr) for _, _, _, _, (addr, *_) in info))
